@@ -45,10 +45,12 @@ from beet.library.resource_pack import (
     Blockstate,
     Font,
     FragmentShader,
+    GlslShader,
     GlyphSizeFile,
+    Language,
     Model,
+    Shader,
     ShaderPost,
-    ShaderProgram,
     Text,
     Texture,
     TextureMcmeta,
@@ -175,13 +177,15 @@ def get_builtin_directives() -> Dict[
 
         "blockstate":      NamespacedResourceDirective(Blockstate),
         "model":           NamespacedResourceDirective(Model),
+        "language":        NamespacedResourceDirective(Language),
         "font":            NamespacedResourceDirective(Font),
         "glyph_sizes":     NamespacedResourceDirective(GlyphSizeFile),
         "truetype_font":   NamespacedResourceDirective(TrueTypeFont),
         "shader_post":     NamespacedResourceDirective(ShaderPost),
-        "shader_program":  NamespacedResourceDirective(ShaderProgram),
+        "shader":          NamespacedResourceDirective(Shader),
         "fragment_shader": NamespacedResourceDirective(FragmentShader),
         "vertex_shader":   NamespacedResourceDirective(VertexShader),
+        "glsl_shader":     NamespacedResourceDirective(GlslShader),
         "text":            NamespacedResourceDirective(Text),
         "texture_mcmeta":  NamespacedResourceDirective(TextureMcmeta),
         "texture":         NamespacedResourceDirective(Texture),
